/*
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.inteligr8.activiti.doclet;

import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/**
 * @author brian@inteligr8.com
 */
public class BeanFreemarkerModel implements JavadocDocumentable, JavadocTaggable {
	
	private String title;
	
	private String apiName;
	
	private String beanId;
	
	private String docFirstSentence;

	private String docBody;
	
	private MethodSignatureFreemarkerModel delegateMethod;

	private MethodSignatureFreemarkerModel executionListenerMethod;

	private MethodSignatureFreemarkerModel taskListenerMethod;

	private Map<String, List<String>> tags = new LinkedHashMap<>();

	private List<ReferenceFreemarkerModel> seeRefs = new LinkedList<>();
	
	private List<MethodFreemarkerModel> methods = new LinkedList<>();

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getApiName() {
		return apiName;
	}

	public void setApiName(String apiName) {
		this.apiName = apiName;
	}

	public String getBeanId() {
		return beanId;
	}

	public void setBeanId(String beanId) {
		this.beanId = beanId;
	}

	public String getDocFirstSentence() {
		return docFirstSentence;
	}

	public void setDocFirstSentence(String docFirstSentence) {
		this.docFirstSentence = docFirstSentence;
	}

	public String getDocBody() {
		return docBody;
	}

	public void setDocBody(String docBody) {
		this.docBody = docBody;
	}
	
	public boolean isHasDelegate() {
		return this.delegateMethod != null || this.executionListenerMethod != null || this.taskListenerMethod != null;
	}
	
	public MethodSignatureFreemarkerModel getDelegateMethod() {
		return delegateMethod;
	}
	
	public void setDelegateMethod(MethodSignatureFreemarkerModel delegateMethod) {
		this.delegateMethod = delegateMethod;
	}
	
	public MethodSignatureFreemarkerModel getExecutionListenerMethod() {
		return executionListenerMethod;
	}
	
	public void setExecutionListenerMethod(MethodSignatureFreemarkerModel executionListenerMethod) {
		this.executionListenerMethod = executionListenerMethod;
	}
	
	public MethodSignatureFreemarkerModel getTaskListenerMethod() {
		return taskListenerMethod;
	}
	
	public void setTaskListenerMethod(MethodSignatureFreemarkerModel taskListenerMethod) {
		this.taskListenerMethod = taskListenerMethod;
	}

	public Map<String, List<String>> getTags() {
		return tags;
	}

	public void setTags(Map<String, List<String>> tags) {
		this.tags = tags;
	}
	
	@Override
	public List<ReferenceFreemarkerModel> getSeeRefs() {
		return seeRefs;
	}
	
	public void setSeeRefs(List<ReferenceFreemarkerModel> seeRefs) {
		this.seeRefs = seeRefs;
	}

	public List<MethodFreemarkerModel> getMethods() {
		return methods;
	}

	public void setMethods(List<MethodFreemarkerModel> methods) {
		this.methods = methods;
	}

}
