# ${title}<#if apiName??>: ${apiName}</#if>: `${beanId}`
<#if (tags.author?? || tags.since?? || tags.version?? || tags.deprecated??)>

<#if tags.author??><#list tags.author as author>*Author*: ${author}</#list>
</#if><#if tags.since??>*Since Version*: ${tags.since[0]}
</#if><#if tags.version??>*Version*: ${tags.version[0]}
</#if><#if tags.deprecated??>*Deprecated*</#if></#if>

<#if docBody??>${docBody}<#else>No documentation available.</#if>
<#if (tags.see?? || seeRefs?size > 0)>

<#list seeRefs as seeRef><#if seeRef.methodName == "">
*See Also*: [`${seeRef.beanId}`](bean-${seeRef.beanId}.md)
<#elseif seeRef.methodName == "delegate">
*See Also*: [`${seeRef.beanId}`](bean-${seeRef.beanId}.md#${seeRef.methodName})
<#else>
*See Also*: [`${seeRef.beanId}.${seeRef.methodName}`](bean-${seeRef.beanId}.md#${seeRef.methodName})
</#if></#list><#if tags.see??><#list tags.see as see>
*See Also*: ${see}
</#list></#if></#if>
<#if hasDelegate>

## <a name="delegate"></a> Delegate Expression Uses

This bean may be used as a *Delegate* using the "Delegate Expression" field as shown in the snippet below.

```javascript
${r"${"}${beanId}${r"}"}
```

<#if delegateMethod?? || executionListenerMethod?? || taskListenerMethod??>
<#assign taskUses = [] />
<#if delegateMethod??><#assign taskUses = taskUses + ["**Service Task**"] /><#assign _delegateMethod = delegateMethod /></#if>
<#if executionListenerMethod??><#assign taskUses = taskUses + ["**Execution Listener**"] /><#assign _delegateMethod = executionListenerMethod /></#if>
<#if taskListenerMethod??><#assign taskUses = taskUses + ["**Task Listener**"] /><#assign _delegateMethod = taskListenerMethod /></#if>
You may use it in a ${taskUses?join(" or ")}.
<@sigdoc sig=_delegateMethod showParams=false/>
</#if></#if><#if (methods?size > 0)>

## Expression Uses

This bean and its methods may be used in any "Expression" field or script in a Script Task in Activiti.

| Method Name                      | Brief Documentation      |
| -------------------------------- | ------------------------ |
<#list methods as method><#assign nameColumn = "[`${method.methodName}`](#${method.methodName})">
| ${nameColumn?right_pad(32)} | <#if method.docFirstSentence??>${method.docFirstSentence?right_pad(24)}<#else>No documentation available.</#if> |
</#list>

<#list methods as method>
### <a name="${method.methodName}"></a> `${method.methodName}`

<#list method.signatures as sig>
**`${beanId}.${sig.methodSignature}`**
<@sigdoc sig=sig showParams=true/>
</#list></#list></#if>

---

[Back to Index](index.md)

Generated by the [Inteligr8](https://inteligr8.com) [Activiti API Doclet](https://bitbucket.org/inteligr8/activiti-api-doclet).

<#macro sigdoc sig showParams>
<#if (sig.tags.author?? || sig.tags.since?? || sig.tags.version?? || sig.tags.deprecated??)>

<#if sig.tags.author??><#list sig.tags.author as author>*Author*: ${author}</#list>
</#if><#if sig.tags.since??>*Since Version*: ${sig.tags.since[0]}
</#if><#if sig.tags.version??>*Version*: ${sig.tags.version[0]}
</#if><#if sig.tags.deprecated??>*Deprecated*</#if></#if>

<#if sig.docBody??>${sig.docBody}<#else>No documentation available.</#if>
<#if ((showParams && sig.params?size > 0) || sig.bpmnFields?size > 0 || sig.variablesIn?size > 0)>

| Input Type               | Name                     | Java Type                                        | Documentation                      |
| ------------------------ | ------------------------ | ------------------------------------------------ | ---------------------------------- |
<#if showParams><#list sig.params as paramName, param>
| Method Parameter         | ${("`" + paramName + "`")?right_pad(24)} | ${("`" + param.type + "`")?right_pad(48)} | <#if (param.comment?? && param.comment?length > 0)>${param.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list></#if>
<#if (sig.bpmnFields?size > 0)>
<#list sig.bpmnFields as fieldName, field>
| BPMN Field               | ${("`" + fieldName + "`")?right_pad(24)} | ${("")?right_pad(48)} | <#if (field.comment?? && field.comment?length > 0)>${field.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list>
</#if>
<#if (sig.variablesIn?size > 0)>
<#list sig.variablesIn as varName, var>
| Activiti Variable        | ${("`" + varName + "`")?right_pad(24)} | ${("")?right_pad(48)} | <#if (var.comment?? && var.comment?length > 0)>${var.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list>
</#if>
</#if>
<#if (sig.returnType?? || sig.variablesOut?size > 0 || sig.throwTypes?size > 0)>

| Result Type              | Java Type, Name, or Error Code                   | Documentation                    |
| ------------------------ | ------------------------------------------------ | -------------------------------- |
<#if sig.returnType??>
| Return Value             | ${("`" + sig.returnType + "`")?right_pad(48)} | <#if (sig.tags.return?? && sig.tags.return[0]?length > 0)>${sig.tags.return[0]?right_pad(32)}<#else>No documentation available.</#if> |
</#if>
<#if (sig.variablesOut?size > 0)>
<#list sig.variablesOut as varName, var>
| Activiti Variable        | ${("`" + varName + "`")?right_pad(48)} | <#if (var.comment?? && var.comment?length > 0)>${var.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list>
</#if>
<#if (sig.throwTypes?size > 0)>
<#list sig.throwTypes as throwType, throw>
| Thrown Exception         | ${("`" + throwType + "`")?right_pad(48)} | <#if (throw.comment?? && throw.comment?length > 0)>${throw.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list>
</#if>
<#if (sig.bpmnErrors?size > 0)>
<#list sig.bpmnErrors as errorCode, bpmnError>
| Thrown BPMN Error        | ${("`" + errorCode + "`")?right_pad(48)} | <#if (bpmnError.comment?? && bpmnError.comment?length > 0)>${bpmnError.comment?right_pad(32)}<#else>No documentation available.</#if> |
</#list>
</#if>
</#if>
<#if (sig.tags.see?? || sig.seeRefs?size > 0)>

<#list sig.seeRefs as seeRef><#if seeRef.methodName == "">
*See Also*: [`${seeRef.beanId}`](bean-${seeRef.beanId}.md)
<#elseif seeRef.methodName == "delegate">
*See Also*: [`${seeRef.beanId}`](bean-${seeRef.beanId}.md#${seeRef.methodName})
<#else>
*See Also*: [`${seeRef.beanId}.${seeRef.methodName}`](bean-${seeRef.beanId}.md#${seeRef.methodName})
</#if></#list><#if sig.tags.see??><#list sig.tags.see as see>
*See Also*: ${see}
</#list>
</#if>
</#if>
</#macro>